Index: webrtc/p2p/base/p2ptransportchannel.h |
diff --git a/webrtc/p2p/base/p2ptransportchannel.h b/webrtc/p2p/base/p2ptransportchannel.h |
index 7d5e304bb3318b6cd959e6b6445a0d801f71b462..25510c2f6418bb2cebe98d0dc86b7a3a486f8a9f 100644 |
--- a/webrtc/p2p/base/p2ptransportchannel.h |
+++ b/webrtc/p2p/base/p2ptransportchannel.h |
@@ -221,8 +221,8 @@ class P2PTransportChannel : public TransportChannelImpl, |
// A transport channel is weak if the current best connection is either |
// not receiving or not writable, or if there is no best connection at all. |
bool weak() const; |
- // Returns true if it's possible to send packets on this channel. |
- bool ReadyToSend() const; |
+ // Returns true if it's possible to send packets on |connection|. |
+ bool ReadyToSend(Connection* connection) const; |
void UpdateConnectionStates(); |
void RequestSortAndStateUpdate(); |
// Start pinging if we haven't already started, and we now have a connection |